embassy-rp

Crates

git

Versions

rp235xb

Flavors

Pin

Trait Pin 

pub trait Pin:
    PeripheralType
    + Into<AnyPin>
    + SealedPin
    + Sized
    + 'static {
    // Provided methods
    fn pin(&self) -> u8 { ... }
    fn bank(&self) -> Bank { ... }
}
Interface for a Pin that can be configured by an Input or Output driver, or converted to an AnyPin.

Provided Methods

fn pin(&self) -> u8

Returns the pin number within a bank

fn bank(&self) -> Bank

Returns the bank of this pin

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors